imp_acc: Acceptance rate of truncated univariate normal distribution...

View source: R/imp_acc.R

imp_accR Documentation

Acceptance rate of truncated univariate normal distribution rejection sampling

Description

imp_acc calculates the acceptance rate of truncated univariate standardized normal distribution rejection sampling for the truncation interval (a,b).

Usage

imp_acc(a, b)

Arguments

a

lower bound for truncation.

b

upper bound for truncation.

Examples

imp_acc(1,Inf) # Case 1: [a,infty)
imp_acc(-1,1) # Case 2: 0 in [a,b], a<0<b
imp_acc(1,2) # Case 3: [a,b], a>=0


tmvmixnorm documentation built on May 11, 2026, 9:07 a.m.