| imp_acc | R Documentation |
imp_acc calculates the acceptance rate of truncated univariate standardized normal distribution rejection sampling for the truncation interval (a,b).
imp_acc(a, b)
a |
lower bound for truncation. |
b |
upper bound for truncation. |
imp_acc(1,Inf) # Case 1: [a,infty)
imp_acc(-1,1) # Case 2: 0 in [a,b], a<0<b
imp_acc(1,2) # Case 3: [a,b], a>=0
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.